# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional

try:
    from pydantic.v1 import BaseModel, Field, conint
except ImportError:
    from pydantic import BaseModel, Field, conint

from mozart_api.models.overlay_play_request_from_usb_from_usb import (
    OverlayPlayRequestFromUsbFromUsb,
)
from mozart_api.models.overlay_play_request_text_to_speech_text_to_speech import (
    OverlayPlayRequestTextToSpeechTextToSpeech,
)
from mozart_api.models.uri import Uri


class OverlayPlayRequest(BaseModel):
    """
    OverlayPlayRequest
    """

    volume_absolute: Optional[conint(strict=True, le=100, ge=0)] = Field(
        default=None,
        alias="volumeAbsolute",
        description="An optional absolute volume level at which to play the URI. If not provided, the URI will play at the currently configured volume level on the product. The level should be provided in volume steps [0, 100] ",
    )
    uri: Optional[Uri] = None
    text_to_speech: Optional[OverlayPlayRequestTextToSpeechTextToSpeech] = Field(
        default=None, alias="textToSpeech"
    )
    from_usb: Optional[OverlayPlayRequestFromUsbFromUsb] = Field(
        default=None, alias="fromUsb"
    )
    __properties = ["volumeAbsolute", "uri", "textToSpeech", "fromUsb"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OverlayPlayRequest:
        """Create an instance of OverlayPlayRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of uri
        if self.uri:
            _dict["uri"] = self.uri.to_dict()
        # override the default output from pydantic by calling `to_dict()` of text_to_speech
        if self.text_to_speech:
            _dict["textToSpeech"] = self.text_to_speech.to_dict()
        # override the default output from pydantic by calling `to_dict()` of from_usb
        if self.from_usb:
            _dict["fromUsb"] = self.from_usb.to_dict()
        # set to None if volume_absolute (nullable) is None
        # and __fields_set__ contains the field
        if self.volume_absolute is None and "volume_absolute" in self.__fields_set__:
            _dict["volumeAbsolute"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OverlayPlayRequest:
        """Create an instance of OverlayPlayRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return OverlayPlayRequest.parse_obj(obj)

        _obj = OverlayPlayRequest.parse_obj(
            {
                "volume_absolute": obj.get("volumeAbsolute"),
                "uri": (
                    Uri.from_dict(obj.get("uri"))
                    if obj.get("uri") is not None
                    else None
                ),
                "text_to_speech": (
                    OverlayPlayRequestTextToSpeechTextToSpeech.from_dict(
                        obj.get("textToSpeech")
                    )
                    if obj.get("textToSpeech") is not None
                    else None
                ),
                "from_usb": (
                    OverlayPlayRequestFromUsbFromUsb.from_dict(obj.get("fromUsb"))
                    if obj.get("fromUsb") is not None
                    else None
                ),
            }
        )
        return _obj



# coding: utf-8

# flake8: noqa
"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from mozart_api.models.action import Action
from mozart_api.models.alarm_timer_event_data import AlarmTimerEventData
from mozart_api.models.alarm_triggered_info import AlarmTriggeredInfo
from mozart_api.models.ambience import Ambience
from mozart_api.models.ambience_feature import AmbienceFeature
from mozart_api.models.ambience_range import AmbienceRange
from mozart_api.models.art import Art
from mozart_api.models.balance import Balance
from mozart_api.models.balance_feature import BalanceFeature
from mozart_api.models.balance_range import BalanceRange
from mozart_api.models.bass import Bass
from mozart_api.models.bass_feature import BassFeature
from mozart_api.models.bass_management import BassManagement
from mozart_api.models.bass_management_feature import BassManagementFeature
from mozart_api.models.bass_management_range import BassManagementRange
from mozart_api.models.bass_range import BassRange
from mozart_api.models.battery_state import BatteryState
from mozart_api.models.beo_remote_button import BeoRemoteButton
from mozart_api.models.beolink_available_listener import BeolinkAvailableListener
from mozart_api.models.beolink_experience import BeolinkExperience
from mozart_api.models.beolink_experiences_result import BeolinkExperiencesResult
from mozart_api.models.beolink_join_request import BeolinkJoinRequest
from mozart_api.models.beolink_join_result import BeolinkJoinResult
from mozart_api.models.beolink_leader import BeolinkLeader
from mozart_api.models.beolink_listener import BeolinkListener
from mozart_api.models.beolink_peer import BeolinkPeer
from mozart_api.models.bluetooth_device import BluetoothDevice
from mozart_api.models.bluetooth_device_list import BluetoothDeviceList
from mozart_api.models.button_event import ButtonEvent
from mozart_api.models.compression import Compression
from mozart_api.models.compression_feature import CompressionFeature
from mozart_api.models.compression_range import CompressionRange
from mozart_api.models.content_item import ContentItem
from mozart_api.models.directivity import Directivity
from mozart_api.models.directivity_feature import DirectivityFeature
from mozart_api.models.directivity_range import DirectivityRange
from mozart_api.models.error_model import ErrorModel
from mozart_api.models.fader import Fader
from mozart_api.models.fader_feature import FaderFeature
from mozart_api.models.fader_range import FaderRange
from mozart_api.models.hdmi_input import HdmiInput
from mozart_api.models.hdmi_video_format import HdmiVideoFormat
from mozart_api.models.home_control_ixp import HomeControlIxp
from mozart_api.models.home_control_uri import HomeControlUri
from mozart_api.models.install_record_id_state import InstallRecordIdState
from mozart_api.models.latency_profile import LatencyProfile
from mozart_api.models.lge_tv_sound_settings import LgeTvSoundSettings
from mozart_api.models.listening_mode import ListeningMode
from mozart_api.models.listening_mode_features import ListeningModeFeatures
from mozart_api.models.listening_mode_props import ListeningModeProps
from mozart_api.models.listening_mode_ref import ListeningModeRef
from mozart_api.models.listening_mode_trigger import ListeningModeTrigger
from mozart_api.models.loudness import Loudness
from mozart_api.models.microphone_state import MicrophoneState
from mozart_api.models.microphones_state import MicrophonesState
from mozart_api.models.overlay_play_request import OverlayPlayRequest
from mozart_api.models.overlay_play_request_common import OverlayPlayRequestCommon
from mozart_api.models.overlay_play_request_from_usb import OverlayPlayRequestFromUsb
from mozart_api.models.overlay_play_request_from_usb_from_usb import (
    OverlayPlayRequestFromUsbFromUsb,
)
from mozart_api.models.overlay_play_request_text_to_speech import (
    OverlayPlayRequestTextToSpeech,
)
from mozart_api.models.overlay_play_request_text_to_speech_text_to_speech import (
    OverlayPlayRequestTextToSpeechTextToSpeech,
)
from mozart_api.models.overlay_play_request_uri import OverlayPlayRequestUri
from mozart_api.models.paired_remote import PairedRemote
from mozart_api.models.paired_remote_response import PairedRemoteResponse
from mozart_api.models.play_queue_item import PlayQueueItem
from mozart_api.models.play_queue_item_type import PlayQueueItemType
from mozart_api.models.play_queue_settings import PlayQueueSettings
from mozart_api.models.playback_content_metadata import PlaybackContentMetadata
from mozart_api.models.playback_error import PlaybackError
from mozart_api.models.playback_progress import PlaybackProgress
from mozart_api.models.playback_state import PlaybackState
from mozart_api.models.power_link_trigger import PowerLinkTrigger
from mozart_api.models.power_state_enum import PowerStateEnum
from mozart_api.models.preset import Preset
from mozart_api.models.product_curtain_status import ProductCurtainStatus
from mozart_api.models.product_friendly_name import ProductFriendlyName
from mozart_api.models.product_state import ProductState
from mozart_api.models.remote_menu_item import RemoteMenuItem
from mozart_api.models.remote_menu_item_properties import RemoteMenuItemProperties
from mozart_api.models.remote_ui_key_state import RemoteUIKeyState
from mozart_api.models.rendering_state import RenderingState
from mozart_api.models.room_compensation import RoomCompensation
from mozart_api.models.room_compensation_current_measurement import (
    RoomCompensationCurrentMeasurement,
)
from mozart_api.models.room_compensation_debug import RoomCompensationDebug
from mozart_api.models.room_compensation_enabled import RoomCompensationEnabled
from mozart_api.models.room_compensation_error_details import (
    RoomCompensationErrorDetails,
)
from mozart_api.models.room_compensation_feature import RoomCompensationFeature
from mozart_api.models.room_compensation_info import RoomCompensationInfo
from mozart_api.models.room_compensation_measurement_error import (
    RoomCompensationMeasurementError,
)
from mozart_api.models.room_compensation_properties import RoomCompensationProperties
from mozart_api.models.room_compensation_range import RoomCompensationRange
from mozart_api.models.room_compensation_response import RoomCompensationResponse
from mozart_api.models.room_compensation_result import RoomCompensationResult
from mozart_api.models.room_compensation_state import RoomCompensationState
from mozart_api.models.room_compensation_state_value import RoomCompensationStateValue
from mozart_api.models.room_compensation_type import RoomCompensationType
from mozart_api.models.room_compensation_version import RoomCompensationVersion
from mozart_api.models.scene import Scene
from mozart_api.models.scene_classification import SceneClassification
from mozart_api.models.scene_match import SceneMatch
from mozart_api.models.scene_properties import SceneProperties
from mozart_api.models.scene_trigger_base_properties import SceneTriggerBaseProperties
from mozart_api.models.software_update_state import SoftwareUpdateState
from mozart_api.models.software_update_status import SoftwareUpdateStatus
from mozart_api.models.sound_adjustments import SoundAdjustments
from mozart_api.models.sound_feature_set import SoundFeatureSet
from mozart_api.models.sound_settings import SoundSettings
from mozart_api.models.sound_tone_touch import SoundToneTouch
from mozart_api.models.source import Source
from mozart_api.models.source_array import SourceArray
from mozart_api.models.source_type_enum import SourceTypeEnum
from mozart_api.models.spatial_envelopment import SpatialEnvelopment
from mozart_api.models.spatial_envelopment_feature import SpatialEnvelopmentFeature
from mozart_api.models.spatial_envelopment_range import SpatialEnvelopmentRange
from mozart_api.models.spatial_height import SpatialHeight
from mozart_api.models.spatial_height_feature import SpatialHeightFeature
from mozart_api.models.spatial_height_range import SpatialHeightRange
from mozart_api.models.spatial_processing import SpatialProcessing
from mozart_api.models.spatial_processing_feature import SpatialProcessingFeature
from mozart_api.models.spatial_processing_range import SpatialProcessingRange
from mozart_api.models.spatial_surround import SpatialSurround
from mozart_api.models.spatial_surround_feature import SpatialSurroundFeature
from mozart_api.models.spatial_surround_range import SpatialSurroundRange
from mozart_api.models.spatial_width import SpatialWidth
from mozart_api.models.spatial_width_feature import SpatialWidthFeature
from mozart_api.models.spatial_width_range import SpatialWidthRange
from mozart_api.models.speaker_group import SpeakerGroup
from mozart_api.models.speaker_group_member import SpeakerGroupMember
from mozart_api.models.speaker_group_member_location import SpeakerGroupMemberLocation
from mozart_api.models.speaker_group_overview import SpeakerGroupOverview
from mozart_api.models.speaker_link_member_status import SpeakerLinkMemberStatus
from mozart_api.models.speaker_link_status import SpeakerLinkStatus
from mozart_api.models.speaker_role_enum import SpeakerRoleEnum
from mozart_api.models.speech_enhance import SpeechEnhance
from mozart_api.models.speech_enhance_feature import SpeechEnhanceFeature
from mozart_api.models.speech_enhance_range import SpeechEnhanceRange
from mozart_api.models.stand_connected import StandConnected
from mozart_api.models.stand_movement import StandMovement
from mozart_api.models.stand_position import StandPosition
from mozart_api.models.tone_touch import ToneTouch
from mozart_api.models.tone_touch_type import ToneTouchType
from mozart_api.models.tone_touch_type_range import ToneTouchTypeRange
from mozart_api.models.tone_touch_x_feature import ToneTouchXFeature
from mozart_api.models.tone_touch_y_feature import ToneTouchYFeature
from mozart_api.models.treble import Treble
from mozart_api.models.treble_feature import TrebleFeature
from mozart_api.models.treble_range import TrebleRange
from mozart_api.models.tv_info_event_data import TvInfoEventData
from mozart_api.models.tv_integration_types import TvIntegrationTypes
from mozart_api.models.tv_properties import TvProperties
from mozart_api.models.tv_sound_settings import TvSoundSettings
from mozart_api.models.tv_state import TvState
from mozart_api.models.uri import Uri
from mozart_api.models.user_flow import UserFlow
from mozart_api.models.video_pixel_format import VideoPixelFormat
from mozart_api.models.video_timings import VideoTimings
from mozart_api.models.volume_level import VolumeLevel
from mozart_api.models.volume_mute import VolumeMute
from mozart_api.models.volume_settings import VolumeSettings
from mozart_api.models.volume_state import VolumeState
from mozart_api.models.web_socket_event_active_hdmi_input_signal import (
    WebSocketEventActiveHdmiInputSignal,
)
from mozart_api.models.web_socket_event_active_listening_mode import (
    WebSocketEventActiveListeningMode,
)
from mozart_api.models.web_socket_event_active_speaker_group import (
    WebSocketEventActiveSpeakerGroup,
)
from mozart_api.models.web_socket_event_alarm_timer import WebSocketEventAlarmTimer
from mozart_api.models.web_socket_event_alarm_triggered import (
    WebSocketEventAlarmTriggered,
)
from mozart_api.models.web_socket_event_battery import WebSocketEventBattery
from mozart_api.models.web_socket_event_beo_remote_button import (
    WebSocketEventBeoRemoteButton,
)
from mozart_api.models.web_socket_event_beolink_experiences_result import (
    WebSocketEventBeolinkExperiencesResult,
)
from mozart_api.models.web_socket_event_beolink_join_result import (
    WebSocketEventBeolinkJoinResult,
)
from mozart_api.models.web_socket_event_button import WebSocketEventButton
from mozart_api.models.web_socket_event_curtains import WebSocketEventCurtains
from mozart_api.models.web_socket_event_hdmi_video_format_signal import (
    WebSocketEventHdmiVideoFormatSignal,
)
from mozart_api.models.web_socket_event_notification import WebSocketEventNotification
from mozart_api.models.web_socket_event_playback_error import (
    WebSocketEventPlaybackError,
)
from mozart_api.models.web_socket_event_playback_metadata import (
    WebSocketEventPlaybackMetadata,
)
from mozart_api.models.web_socket_event_playback_progress import (
    WebSocketEventPlaybackProgress,
)
from mozart_api.models.web_socket_event_playback_source import (
    WebSocketEventPlaybackSource,
)
from mozart_api.models.web_socket_event_playback_state import (
    WebSocketEventPlaybackState,
)
from mozart_api.models.web_socket_event_power_state import WebSocketEventPowerState
from mozart_api.models.web_socket_event_puc_install_remote_id_status import (
    WebSocketEventPucInstallRemoteIdStatus,
)
from mozart_api.models.web_socket_event_role import WebSocketEventRole
from mozart_api.models.web_socket_event_room_compensation_current_measurement_event import (
    WebSocketEventRoomCompensationCurrentMeasurementEvent,
)
from mozart_api.models.web_socket_event_room_compensation_state import (
    WebSocketEventRoomCompensationState,
)
from mozart_api.models.web_socket_event_software_update_state import (
    WebSocketEventSoftwareUpdateState,
)
from mozart_api.models.web_socket_event_sound_settings import (
    WebSocketEventSoundSettings,
)
from mozart_api.models.web_socket_event_source_change import WebSocketEventSourceChange
from mozart_api.models.web_socket_event_speaker_group_changed import (
    WebSocketEventSpeakerGroupChanged,
)
from mozart_api.models.web_socket_event_speaker_link_status_changed import (
    WebSocketEventSpeakerLinkStatusChanged,
)
from mozart_api.models.web_socket_event_stand_connected import (
    WebSocketEventStandConnected,
)
from mozart_api.models.web_socket_event_stand_position import (
    WebSocketEventStandPosition,
)
from mozart_api.models.web_socket_event_tv_info import WebSocketEventTvInfo
from mozart_api.models.web_socket_event_volume import WebSocketEventVolume
from mozart_api.models.web_socket_event_wisa_out_state import WebSocketEventWisaOutState
from mozart_api.models.websocket_notification_tag import WebsocketNotificationTag
from mozart_api.models.wisa_out_state import WisaOutState



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional

try:
    from pydantic.v1 import BaseModel, Field, StrictBool, StrictStr, conint, conlist
except ImportError:
    from pydantic import BaseModel, Field, StrictBool, StrictStr, conint, conlist

from mozart_api.models.latency_profile import LatencyProfile
from mozart_api.models.speaker_group_member import SpeakerGroupMember


class SpeakerGroup(BaseModel):
    """
    SpeakerGroup
    """

    crossover_frequency: Optional[conint(strict=True, le=300, ge=20)] = Field(
        default=None,
        alias="crossoverFrequency",
        description="Crossover frequency for bass management in Hz",
    )
    enable_phase_compensation: Optional[StrictBool] = Field(
        default=None,
        alias="enablePhaseCompensation",
        description="Enable phase compensation in bass management.",
    )
    friendly_name: Optional[StrictStr] = Field(
        default=None,
        alias="friendlyName",
        description="Friendly name of the SpeakerGroup. Required when creating a new group ",
    )
    id: Optional[StrictStr] = None
    is_deleteable: Optional[StrictBool] = Field(default=None, alias="isDeleteable")
    items: Optional[conlist(SpeakerGroupMember)] = None
    latency_profile: Optional[LatencyProfile] = Field(
        default=None, alias="latencyProfile"
    )
    room_compensation_id: Optional[StrictStr] = Field(
        default=None,
        alias="roomCompensationId",
        description="ID of the calculated coefficents for this group, made during advanced room compensation. When updating an existing group, an empty string will clear roomCompensationId. ",
    )
    speaker_preset: Optional[conint(strict=True, le=99, ge=0)] = Field(
        default=None,
        alias="speakerPreset",
        description="Speaker preset / listening mode eg. BL28 curtain position etc.",
    )
    __properties = [
        "crossoverFrequency",
        "enablePhaseCompensation",
        "friendlyName",
        "id",
        "isDeleteable",
        "items",
        "latencyProfile",
        "roomCompensationId",
        "speakerPreset",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SpeakerGroup:
        """Create an instance of SpeakerGroup from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in items (list)
        _items = []
        if self.items:
            for _item in self.items:
                if _item:
                    _items.append(_item.to_dict())
            _dict["items"] = _items
        # override the default output from pydantic by calling `to_dict()` of latency_profile
        if self.latency_profile:
            _dict["latencyProfile"] = self.latency_profile.to_dict()
        # set to None if crossover_frequency (nullable) is None
        # and __fields_set__ contains the field
        if (
            self.crossover_frequency is None
            and "crossover_frequency" in self.__fields_set__
        ):
            _dict["crossoverFrequency"] = None

        # set to None if enable_phase_compensation (nullable) is None
        # and __fields_set__ contains the field
        if (
            self.enable_phase_compensation is None
            and "enable_phase_compensation" in self.__fields_set__
        ):
            _dict["enablePhaseCompensation"] = None

        # set to None if friendly_name (nullable) is None
        # and __fields_set__ contains the field
        if self.friendly_name is None and "friendly_name" in self.__fields_set__:
            _dict["friendlyName"] = None

        # set to None if is_deleteable (nullable) is None
        # and __fields_set__ contains the field
        if self.is_deleteable is None and "is_deleteable" in self.__fields_set__:
            _dict["isDeleteable"] = None

        # set to None if items (nullable) is None
        # and __fields_set__ contains the field
        if self.items is None and "items" in self.__fields_set__:
            _dict["items"] = None

        # set to None if room_compensation_id (nullable) is None
        # and __fields_set__ contains the field
        if (
            self.room_compensation_id is None
            and "room_compensation_id" in self.__fields_set__
        ):
            _dict["roomCompensationId"] = None

        # set to None if speaker_preset (nullable) is None
        # and __fields_set__ contains the field
        if self.speaker_preset is None and "speaker_preset" in self.__fields_set__:
            _dict["speakerPreset"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SpeakerGroup:
        """Create an instance of SpeakerGroup from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SpeakerGroup.parse_obj(obj)

        _obj = SpeakerGroup.parse_obj(
            {
                "crossover_frequency": obj.get("crossoverFrequency"),
                "enable_phase_compensation": obj.get("enablePhaseCompensation"),
                "friendly_name": obj.get("friendlyName"),
                "id": obj.get("id"),
                "is_deleteable": obj.get("isDeleteable"),
                "items": (
                    [SpeakerGroupMember.from_dict(_item) for _item in obj.get("items")]
                    if obj.get("items") is not None
                    else None
                ),
                "latency_profile": (
                    LatencyProfile.from_dict(obj.get("latencyProfile"))
                    if obj.get("latencyProfile") is not None
                    else None
                ),
                "room_compensation_id": obj.get("roomCompensationId"),
                "speaker_preset": obj.get("speakerPreset"),
            }
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional

try:
    from pydantic.v1 import BaseModel, Field, StrictInt, StrictStr
except ImportError:
    from pydantic import BaseModel, Field, StrictInt, StrictStr

from mozart_api.models.tv_integration_types import TvIntegrationTypes


class TvProperties(BaseModel):
    """
    TvProperties
    """

    integration_supported: Optional[TvIntegrationTypes] = Field(
        default=None, alias="integrationSupported"
    )
    name: Optional[StrictStr] = None
    year: Optional[StrictInt] = None
    __properties = ["integrationSupported", "name", "year"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TvProperties:
        """Create an instance of TvProperties from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of integration_supported
        if self.integration_supported:
            _dict["integrationSupported"] = self.integration_supported.to_dict()
        # set to None if name (nullable) is None
        # and __fields_set__ contains the field
        if self.name is None and "name" in self.__fields_set__:
            _dict["name"] = None

        # set to None if year (nullable) is None
        # and __fields_set__ contains the field
        if self.year is None and "year" in self.__fields_set__:
            _dict["year"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TvProperties:
        """Create an instance of TvProperties from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TvProperties.parse_obj(obj)

        _obj = TvProperties.parse_obj(
            {
                "integration_supported": (
                    TvIntegrationTypes.from_dict(obj.get("integrationSupported"))
                    if obj.get("integrationSupported") is not None
                    else None
                ),
                "name": obj.get("name"),
                "year": obj.get("year"),
            }
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional

try:
    from pydantic.v1 import BaseModel, Field, StrictInt, StrictStr, validator
except ImportError:
    from pydantic import BaseModel, Field, StrictInt, StrictStr, validator

from mozart_api.models.software_update_state import SoftwareUpdateState


class SoftwareUpdateStatus(BaseModel):
    """
    SoftwareUpdateStatus
    """

    available_update: Optional[StrictStr] = Field(default=None, alias="availableUpdate")
    last_check: Optional[datetime] = Field(default=None, alias="lastCheck")
    last_update: Optional[datetime] = Field(default=None, alias="lastUpdate")
    software_version: StrictStr = Field(default=..., alias="softwareVersion")
    state: SoftwareUpdateState = Field(...)
    update_progress: Optional[StrictInt] = Field(default=None, alias="updateProgress")
    update_type: Optional[StrictStr] = Field(default=None, alias="updateType")
    __properties = [
        "availableUpdate",
        "lastCheck",
        "lastUpdate",
        "softwareVersion",
        "state",
        "updateProgress",
        "updateType",
    ]

    @validator("update_type")
    def update_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("none", "normal", "critical", "forced"):
            raise ValueError(
                "must be one of enum values ('none', 'normal', 'critical', 'forced')"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SoftwareUpdateStatus:
        """Create an instance of SoftwareUpdateStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of state
        if self.state:
            _dict["state"] = self.state.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SoftwareUpdateStatus:
        """Create an instance of SoftwareUpdateStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SoftwareUpdateStatus.parse_obj(obj)

        _obj = SoftwareUpdateStatus.parse_obj(
            {
                "available_update": obj.get("availableUpdate"),
                "last_check": obj.get("lastCheck"),
                "last_update": obj.get("lastUpdate"),
                "software_version": obj.get("softwareVersion"),
                "state": (
                    SoftwareUpdateState.from_dict(obj.get("state"))
                    if obj.get("state") is not None
                    else None
                ),
                "update_progress": obj.get("updateProgress"),
                "update_type": obj.get("updateType"),
            }
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List

try:
    from pydantic.v1 import BaseModel, Field, StrictStr, conlist, validator
except ImportError:
    from pydantic import BaseModel, Field, StrictStr, conlist, validator

from mozart_api.models.beolink_experience import BeolinkExperience


class BeolinkExperiencesResult(BaseModel):
    """
    BeolinkExperiencesResult
    """

    experiences: conlist(BeolinkExperience) = Field(...)
    request_id: StrictStr = Field(
        default=..., alias="requestID", description="Beolink request ID"
    )
    status: StrictStr = Field(
        default=...,
        description="Current scan status. * busy: there is another scan in progress * timeout: the scan timed out. The results will be partial ",
    )
    __properties = ["experiences", "requestID", "status"]

    @validator("status")
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ("ok", "busy", "timeout"):
            raise ValueError("must be one of enum values ('ok', 'busy', 'timeout')")
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BeolinkExperiencesResult:
        """Create an instance of BeolinkExperiencesResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in experiences (list)
        _items = []
        if self.experiences:
            for _item in self.experiences:
                if _item:
                    _items.append(_item.to_dict())
            _dict["experiences"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BeolinkExperiencesResult:
        """Create an instance of BeolinkExperiencesResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return BeolinkExperiencesResult.parse_obj(obj)

        _obj = BeolinkExperiencesResult.parse_obj(
            {
                "experiences": (
                    [
                        BeolinkExperience.from_dict(_item)
                        for _item in obj.get("experiences")
                    ]
                    if obj.get("experiences") is not None
                    else None
                ),
                "request_id": obj.get("requestID"),
                "status": obj.get("status"),
            }
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional

try:
    from pydantic.v1 import BaseModel, Field, StrictBool, StrictStr, conlist, validator
except ImportError:
    from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist, validator

from mozart_api.models.action import Action


class RemoteMenuItemProperties(BaseModel):
    """
    RemoteMenuItemProperties
    """

    action_list: Optional[conlist(Action)] = Field(
        default=None,
        alias="actionList",
        description="An ordered list of Actions to run on the product",
    )
    scene_list: Optional[conlist(StrictStr)] = Field(
        default=None, alias="sceneList", description="A list of scenes"
    )
    disabled: Optional[StrictBool] = None
    dynamic_list: Optional[StrictStr] = Field(
        default=None,
        alias="dynamicList",
        description="Let mozart create a dynamic list. This list will be attached as children to the menu item. If dynamicList is set it's not possible to change or manipulate any of the children because mozart can alter them at any given time ",
    )
    first_child_menu_item_id: Optional[StrictStr] = Field(
        default=None,
        alias="firstChildMenuItemId",
        description="ID of the first child menu item",
    )
    label: Optional[StrictStr] = Field(
        default=None,
        description="Alternative label, if omitted mozart will try its best",
    )
    next_sibling_menu_item_id: Optional[StrictStr] = Field(
        default=None,
        alias="nextSiblingMenuItemId",
        description="ID of the next sibling menu item",
    )
    parent_menu_item_id: Optional[StrictStr] = Field(
        default=None, alias="parentMenuItemId", description="ID of the parent menu item"
    )
    __properties = [
        "actionList",
        "sceneList",
        "disabled",
        "dynamicList",
        "firstChildMenuItemId",
        "label",
        "nextSiblingMenuItemId",
        "parentMenuItemId",
    ]

    @validator("dynamic_list")
    def dynamic_list_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("none", "radioFavorites"):
            raise ValueError("must be one of enum values ('none', 'radioFavorites')")
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RemoteMenuItemProperties:
        """Create an instance of RemoteMenuItemProperties from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in action_list (list)
        _items = []
        if self.action_list:
            for _item in self.action_list:
                if _item:
                    _items.append(_item.to_dict())
            _dict["actionList"] = _items
        # set to None if disabled (nullable) is None
        # and __fields_set__ contains the field
        if self.disabled is None and "disabled" in self.__fields_set__:
            _dict["disabled"] = None

        # set to None if dynamic_list (nullable) is None
        # and __fields_set__ contains the field
        if self.dynamic_list is None and "dynamic_list" in self.__fields_set__:
            _dict["dynamicList"] = None

        # set to None if first_child_menu_item_id (nullable) is None
        # and __fields_set__ contains the field
        if (
            self.first_child_menu_item_id is None
            and "first_child_menu_item_id" in self.__fields_set__
        ):
            _dict["firstChildMenuItemId"] = None

        # set to None if label (nullable) is None
        # and __fields_set__ contains the field
        if self.label is None and "label" in self.__fields_set__:
            _dict["label"] = None

        # set to None if next_sibling_menu_item_id (nullable) is None
        # and __fields_set__ contains the field
        if (
            self.next_sibling_menu_item_id is None
            and "next_sibling_menu_item_id" in self.__fields_set__
        ):
            _dict["nextSiblingMenuItemId"] = None

        # set to None if parent_menu_item_id (nullable) is None
        # and __fields_set__ contains the field
        if (
            self.parent_menu_item_id is None
            and "parent_menu_item_id" in self.__fields_set__
        ):
            _dict["parentMenuItemId"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RemoteMenuItemProperties:
        """Create an instance of RemoteMenuItemProperties from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RemoteMenuItemProperties.parse_obj(obj)

        _obj = RemoteMenuItemProperties.parse_obj(
            {
                "action_list": (
                    [Action.from_dict(_item) for _item in obj.get("actionList")]
                    if obj.get("actionList") is not None
                    else None
                ),
                "scene_list": obj.get("sceneList"),
                "disabled": obj.get("disabled"),
                "dynamic_list": obj.get("dynamicList"),
                "first_child_menu_item_id": obj.get("firstChildMenuItemId"),
                "label": obj.get("label"),
                "next_sibling_menu_item_id": obj.get("nextSiblingMenuItemId"),
                "parent_menu_item_id": obj.get("parentMenuItemId"),
            }
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional

try:
    from pydantic.v1 import BaseModel, Field, StrictBool, StrictStr, validator
except ImportError:
    from pydantic import BaseModel, Field, StrictBool, StrictStr, validator


class BeolinkExperience(BaseModel):
    """
    BeolinkExperience
    """

    category: StrictStr = Field(default=..., description="Source category")
    id: StrictStr = Field(
        default=..., description='experience id, e.g. "RADIO" or "toslink"'
    )
    linkable: StrictBool = Field(
        default=...,
        description='Linkable means "Does pressing play on this source make sense"',
    )
    name: StrictStr = Field(
        default=..., description='Experience name, e.g. "Bluetooth" or "B&O Radio"'
    )
    product_friendly_name: Optional[StrictStr] = Field(
        default=None,
        alias="productFriendlyName",
        description="Optional product friendly name",
    )
    source_friendly_name: Optional[StrictStr] = Field(
        default=None,
        alias="sourceFriendlyName",
        description="Optional friendly name for source",
    )
    type: StrictStr = Field(
        default=...,
        description="Source type. This corresponds to the exhaustive list or sources provided by the control layer",
    )
    unique_source_id: StrictStr = Field(
        default=...,
        alias="uniqueSourceId",
        description="The actual device jabber id that the experience comes from",
    )
    __properties = [
        "category",
        "id",
        "linkable",
        "name",
        "productFriendlyName",
        "sourceFriendlyName",
        "type",
        "uniqueSourceId",
    ]

    @validator("category")
    def category_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ("TV", "RADIO", "MUSIC", "MEDIA", "UNKNOWN"):
            raise ValueError(
                "must be one of enum values ('TV', 'RADIO', 'MUSIC', 'MEDIA', 'UNKNOWN')"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BeolinkExperience:
        """Create an instance of BeolinkExperience from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BeolinkExperience:
        """Create an instance of BeolinkExperience from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return BeolinkExperience.parse_obj(obj)

        _obj = BeolinkExperience.parse_obj(
            {
                "category": obj.get("category"),
                "id": obj.get("id"),
                "linkable": obj.get("linkable"),
                "name": obj.get("name"),
                "product_friendly_name": obj.get("productFriendlyName"),
                "source_friendly_name": obj.get("sourceFriendlyName"),
                "type": obj.get("type"),
                "unique_source_id": obj.get("uniqueSourceId"),
            }
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional

try:
    from pydantic.v1 import BaseModel, Field, StrictStr, validator
except ImportError:
    from pydantic import BaseModel, Field, StrictStr, validator


class RoomCompensationMeasurementError(BaseModel):
    """
    RoomCompensationMeasurementError
    """

    error: Optional[StrictStr] = Field(
        default=None,
        description="noError:   The measurement went OK. lowSignal:   When there is too low signal in the recording, e.g. due to a loudspeaker being placed at   too great a distance from the microphone. speakerSilent:   No signal could be measured.   Could be because:     - The speaker is powered off or not connected.     - The left/right switch on a wired powerlink speaker is set in the wrong position.     - The speaker is placed in another room behind closed doors. noisy<Left/Right/External>Microphone:   When the recording of the given microphone is too noisy.   Could be because:     - Something is blocking the microphone externalMicrophoneLocation:   When the location of the external microphone is invalid. externalMicrophoneMissing:   If the external microphone was missing/disconnected during a measurement. microphonesDisabled:   If the microphones are either muted or disabled. noisyMeasurement:   When too much background noise has been detected during the measurement internalError:   Something went wrong internally - can not be fixed by the user. Try again. ",
    )
    speaker_id: Optional[StrictStr] = Field(default=None, alias="speakerId")
    __properties = ["error", "speakerId"]

    @validator("error")
    def error_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in (
            "noError",
            "lowSignal",
            "speakerSilent",
            "noisyLeftMicrophone",
            "noisyRightMicrophone",
            "noisyExternalMicrophone",
            "externalMicrophoneLocation",
            "externalMicrophoneMissing",
            "microphonesDisabled",
            "noisyMeasurement",
            "internalError",
        ):
            raise ValueError(
                "must be one of enum values ('noError', 'lowSignal', 'speakerSilent', 'noisyLeftMicrophone', 'noisyRightMicrophone', 'noisyExternalMicrophone', 'externalMicrophoneLocation', 'externalMicrophoneMissing', 'microphonesDisabled', 'noisyMeasurement', 'internalError')"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RoomCompensationMeasurementError:
        """Create an instance of RoomCompensationMeasurementError from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RoomCompensationMeasurementError:
        """Create an instance of RoomCompensationMeasurementError from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RoomCompensationMeasurementError.parse_obj(obj)

        _obj = RoomCompensationMeasurementError.parse_obj(
            {"error": obj.get("error"), "speaker_id": obj.get("speakerId")}
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


try:
    from pydantic.v1 import BaseModel, Field, StrictInt
except ImportError:
    from pydantic import BaseModel, Field, StrictInt


class SpeakerGroupMemberLocation(BaseModel):
    """
    Coordinates of the speaker position in cm. Location is only relevant when the group is based on the automatic role assignment of advanced room compensation. The location is relative to the external microphone used during advanced room compensation measurements:   x=0, y=0, z=0: The location of the external microphone used during measurement.   x<0: To the left of the external microphone.   x>0: To the right of the external microphone.   y<0: Behind the external microphone.   y>0: In front of the external microphone.   z<0: Above the external microphone (may not be reliable).   z>0: Below the external microphone (may not be reliable).   # noqa: E501
    """

    x: StrictInt = Field(...)
    y: StrictInt = Field(...)
    z: StrictInt = Field(...)
    __properties = ["x", "y", "z"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SpeakerGroupMemberLocation:
        """Create an instance of SpeakerGroupMemberLocation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SpeakerGroupMemberLocation:
        """Create an instance of SpeakerGroupMemberLocation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SpeakerGroupMemberLocation.parse_obj(obj)

        _obj = SpeakerGroupMemberLocation.parse_obj(
            {"x": obj.get("x"), "y": obj.get("y"), "z": obj.get("z")}
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional

try:
    from pydantic.v1 import BaseModel, Field, StrictStr, conlist
except ImportError:
    from pydantic import BaseModel, Field, StrictStr, conlist

from mozart_api.models.action import Action
from mozart_api.models.content_item import ContentItem
from mozart_api.models.source_type_enum import SourceTypeEnum


class Preset(BaseModel):
    """
    Preset
    """

    action_list: Optional[conlist(Action)] = Field(
        default=None,
        alias="actionList",
        description="An ordered list of Actions to run on the product",
    )
    scene_list: Optional[conlist(StrictStr)] = Field(
        default=None, alias="sceneList", description="A list of scenes"
    )
    content: Optional[ContentItem] = None
    id: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    source: Optional[SourceTypeEnum] = None
    title: Optional[StrictStr] = None
    __properties = [
        "actionList",
        "sceneList",
        "content",
        "id",
        "name",
        "source",
        "title",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Preset:
        """Create an instance of Preset from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in action_list (list)
        _items = []
        if self.action_list:
            for _item in self.action_list:
                if _item:
                    _items.append(_item.to_dict())
            _dict["actionList"] = _items
        # override the default output from pydantic by calling `to_dict()` of content
        if self.content:
            _dict["content"] = self.content.to_dict()
        # override the default output from pydantic by calling `to_dict()` of source
        if self.source:
            _dict["source"] = self.source.to_dict()
        # set to None if name (nullable) is None
        # and __fields_set__ contains the field
        if self.name is None and "name" in self.__fields_set__:
            _dict["name"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Preset:
        """Create an instance of Preset from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Preset.parse_obj(obj)

        _obj = Preset.parse_obj(
            {
                "action_list": (
                    [Action.from_dict(_item) for _item in obj.get("actionList")]
                    if obj.get("actionList") is not None
                    else None
                ),
                "scene_list": obj.get("sceneList"),
                "content": (
                    ContentItem.from_dict(obj.get("content"))
                    if obj.get("content") is not None
                    else None
                ),
                "id": obj.get("id"),
                "name": obj.get("name"),
                "source": (
                    SourceTypeEnum.from_dict(obj.get("source"))
                    if obj.get("source") is not None
                    else None
                ),
                "title": obj.get("title"),
            }
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional

try:
    from pydantic.v1 import (
        BaseModel,
        Field,
        StrictStr,
        conint,
        conlist,
        constr,
        validator,
    )
except ImportError:
    from pydantic import BaseModel, Field, StrictStr, conint, conlist, constr, validator

from mozart_api.models.listening_mode_features import ListeningModeFeatures
from mozart_api.models.listening_mode_trigger import ListeningModeTrigger


class ListeningModeProps(BaseModel):
    """
    ListeningModeProps
    """

    client_ctx: Optional[constr(strict=True, max_length=4096)] = Field(
        default=None,
        alias="clientCtx",
        description="An optional generic string property supplied from the client. If provided, it will be stored without changes. If not supplied, any current clientCtx will remain unchanged. ",
    )
    features: Optional[ListeningModeFeatures] = None
    id: Optional[conint(strict=True, ge=0)] = None
    name: Optional[StrictStr] = Field(default=None, description="Friendly name")
    origin: Optional[StrictStr] = Field(
        default=None,
        description="User created, default or an edited default listening mode",
    )
    role: Optional[StrictStr] = Field(
        default=None, description="Role a listening mode applies to"
    )
    triggers: Optional[conlist(ListeningModeTrigger)] = None
    __properties = ["clientCtx", "features", "id", "name", "origin", "role", "triggers"]

    @validator("origin")
    def origin_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("user", "default", "edited"):
            raise ValueError("must be one of enum values ('user', 'default', 'edited')")
        return value

    @validator("role")
    def role_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("standalone", "multichannel", "all"):
            raise ValueError(
                "must be one of enum values ('standalone', 'multichannel', 'all')"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ListeningModeProps:
        """Create an instance of ListeningModeProps from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of features
        if self.features:
            _dict["features"] = self.features.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in triggers (list)
        _items = []
        if self.triggers:
            for _item in self.triggers:
                if _item:
                    _items.append(_item.to_dict())
            _dict["triggers"] = _items
        # set to None if client_ctx (nullable) is None
        # and __fields_set__ contains the field
        if self.client_ctx is None and "client_ctx" in self.__fields_set__:
            _dict["clientCtx"] = None

        # set to None if role (nullable) is None
        # and __fields_set__ contains the field
        if self.role is None and "role" in self.__fields_set__:
            _dict["role"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ListeningModeProps:
        """Create an instance of ListeningModeProps from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ListeningModeProps.parse_obj(obj)

        _obj = ListeningModeProps.parse_obj(
            {
                "client_ctx": obj.get("clientCtx"),
                "features": (
                    ListeningModeFeatures.from_dict(obj.get("features"))
                    if obj.get("features") is not None
                    else None
                ),
                "id": obj.get("id"),
                "name": obj.get("name"),
                "origin": obj.get("origin"),
                "role": obj.get("role"),
                "triggers": (
                    [
                        ListeningModeTrigger.from_dict(_item)
                        for _item in obj.get("triggers")
                    ]
                    if obj.get("triggers") is not None
                    else None
                ),
            }
        )
        return _obj



"""Helper classes for using auto-generated API."""

# pylint: disable=line-too-long too-many-instance-attributes too-many-public-methods

import asyncio
import contextlib
import json
import logging
import re
from collections import defaultdict
from dataclasses import dataclass
from datetime import time
from typing import Callable, Literal

from aiohttp import ClientSession
from aiohttp.client_exceptions import (
    ClientConnectorError,
    ClientOSError,
    ServerTimeoutError,
)
from inflection import underscore
from mozart_api.api.mozart_api import MozartApi
from mozart_api.api_client import ApiClient
from mozart_api.configuration import Configuration
from mozart_api.exceptions import ApiException
from mozart_api.models import Art, PlaybackContentMetadata

WEBSOCKET_TIMEOUT = 5.0

# Generated section start

NOTIFICATION_TYPES = {
    "active_hdmi_input_signal",
    "active_listening_mode",
    "active_speaker_group",
    "alarm_timer",
    "alarm_triggered",
    "battery",
    "beo_remote_button",
    "beolink_experiences_result",
    "beolink_join_result",
    "button",
    "curtains",
    "hdmi_video_format_signal",
    "notification",
    "playback_error",
    "playback_metadata",
    "playback_progress",
    "playback_source",
    "playback_state",
    "power_state",
    "puc_install_remote_id_status",
    "role",
    "room_compensation_current_measurement_event",
    "room_compensation_state",
    "software_update_state",
    "sound_settings",
    "source_change",
    "speaker_group_changed",
    "speaker_link_status_changed",
    "stand_connected",
    "stand_position",
    "tv_info",
    "volume",
    "wisa_out_state",
}

# Generated section end

logger = logging.getLogger(__name__)


def refactor_name(notification_type: str) -> str:
    """Remove WebSocketEvent prefix from string and convert to snake_case."""
    return underscore(notification_type.removeprefix("WebSocketEvent"))


def time_to_seconds(time_object: time) -> int:
    """Convert time object to number of seconds."""
    return (time_object.hour * 60 * 60) + (time_object.minute * 60) + time_object.second


def check_valid_jid(jid: str) -> bool:
    """Check if a JID is valid."""
    pattern = re.compile(r"(^\d{4})[.](\d{7})[.](\d{8})(@products\.bang-olufsen\.com)$")

    if pattern.fullmatch(jid) is not None:
        return True

    return False


def check_valid_serial_number(serial_number: str) -> bool:
    """Check if a serial_number is valid."""
    return bool(re.fullmatch(r"\d{8}", serial_number))


def get_highest_resolution_artwork(metadata: PlaybackContentMetadata) -> Art:
    """Get the highest resolution Art from provided PlaybackContentMetadata."""

    # Return an empty Art if no artwork is in metadata to ensure no stale artwork
    if not metadata.art:
        return Art()  # type: ignore

    # Dict for sorting images that have size defined by a string
    art_size = {"small": 1, "medium": 2, "large": 3}

    images = []

    # Images either have a key for specifying resolution or a "size" for the image.
    for image in metadata.art:
        # Netradio.
        if image.key:
            images.append(int(image.key.split("x")[0]))
        # Everything else.
        elif image.size:
            images.append(art_size[image.size])

    # Choose the largest image.
    return metadata.art[images.index(max(images))]


class MozartClient(MozartApi):
    """User friendly Mozart REST API and WebSocket client."""

    def __init__(self, host: str) -> None:
        """Initialize Mozart client."""
        self.host = host
        self.websocket_connected = False
        self.websocket_reconnect = False

        self._websocket_listener_active = False
        self._websocket_listener_remote_listener_active = False
        self._websocket_listeners_active = False
        self._websocket_tasks: set[asyncio.Task] = set()

        self._on_connection_lost = None
        self._on_connection = None

        self._on_all_notifications = None
        self._on_all_notifications_raw = None

        self._notification_callbacks: dict[str, Callable | None] = defaultdict()
        self._notification_callbacks.default_factory = lambda: None

        # Configure MozartApi object.
        self.configuration = Configuration(host="http://" + self.host)
        self.configuration.verify_ssl = False

        super().__init__(ApiClient(self.configuration))

    async def close_api_client(self) -> None:
        """Close the API ClientSession."""
        await self.api_client.close()

    async def __aenter__(self):
        """Context entry"""
        if self.api_client.rest_client.pool_manager.closed:
            self.api_client = ApiClient(self.configuration)
        return self

    async def __aexit__(self, exc_type, exc_value, traceback):
        """Context exit."""
        await self.close_api_client()

    async def _check_websocket_connection(
        self,
    ) -> Literal[True] | ClientConnectorError | ClientOSError | ServerTimeoutError:
        """Check if a connection can be made to the device's WebSocket notification channel."""
        try:
            async with ClientSession(conn_timeout=WEBSOCKET_TIMEOUT) as session:
                async with session.ws_connect(
                    f"ws://{self.host}:9339/",
                    timeout=WEBSOCKET_TIMEOUT,
                    receive_timeout=WEBSOCKET_TIMEOUT,
                ) as websocket:
                    if await websocket.receive():
                        return True

        except (ClientConnectorError, ClientOSError, ServerTimeoutError) as error:
            return error

    async def _check_api_connection(
        self,
    ) -> Literal[True] | ApiException | ClientConnectorError | TimeoutError:
        """Check if a connection can be made to the device's REST API."""
        try:
            await self.get_battery_state(_request_timeout=3)
        except (ApiException, ClientConnectorError, TimeoutError) as error:
            return error

        return True

    async def check_device_connection(self, raise_error=False) -> bool:
        """Check API and WebSocket connection."""
        # Don't use a taskgroup as both tasks should always be checked
        tasks: tuple[
            asyncio.Task[
                Literal[True]
                | ClientConnectorError
                | ClientOSError
                | ServerTimeoutError
            ],
            asyncio.Task[
                Literal[True] | ApiException | ClientConnectorError | TimeoutError
            ],
        ] = (
            asyncio.create_task(self._check_websocket_connection(), name="websocket"),
            asyncio.create_task(self._check_api_connection(), name="REST API"),
        )

        # Wait for tasks to complete
        for task in tasks:
            while not task.done():
                await asyncio.sleep(0)

        errors: list[
            ClientConnectorError
            | ClientOSError
            | ServerTimeoutError
            | ApiException
            | TimeoutError
        ] = []

        # Check status
        for task in tasks:
            if (result := task.result()) is not True:
                errors.append(result)

        connection_available = bool(len(errors) == 0)

        # Raise any exceptions
        if not connection_available and raise_error:
            raise ExceptionGroup(f"Can't connect to {self.host}", tuple(errors))

        return connection_available

    async def connect_notifications(
        self, remote_control=False, reconnect=False
    ) -> None:
        """Start the WebSocket listener task(s)."""
        self.websocket_reconnect = reconnect

        # Always add main WebSocket listener
        if not self._websocket_listener_active:
            self._websocket_tasks.add(
                asyncio.create_task(
                    coro=self._websocket_listener(f"ws://{self.host}:9339/"),
                    name=f"{self.host} - listener task",
                )
            )

            self._websocket_listener_active = True

        # Add WebSocket listener for remote control events if defined.
        if not self._websocket_listener_remote_listener_active and remote_control:
            self._websocket_tasks.add(
                asyncio.create_task(
                    coro=self._websocket_listener(
                        f"ws://{self.host}:9339/remoteControl"
                    ),
                    name=f"{self.host} - remote listener task",
                )
            )
            self._websocket_listener_remote_listener_active = True

        self._websocket_listeners_active = True

    def disconnect_notifications(self) -> None:
        """Stop the WebSocket listener tasks."""
        self._websocket_listener_active = False
        self._websocket_listener_remote_listener_active = False
        self._websocket_listeners_active = False

        for task in self._websocket_tasks:
            task.cancel()

        self._websocket_tasks.clear()

    async def _websocket_listener(self, host: str) -> None:
        """WebSocket listener."""
        while True:
            try:
                async with ClientSession(conn_timeout=WEBSOCKET_TIMEOUT) as session:
                    async with session.ws_connect(
                        url=host, heartbeat=WEBSOCKET_TIMEOUT
                    ) as websocket:
                        self.websocket_connected = True

                        if self._on_connection:
                            await self._trigger_callback(self._on_connection)

                        while self._websocket_listeners_active:
                            with contextlib.suppress(asyncio.TimeoutError):
                                # Receive JSON in order to get the Websocket notification name for deserialization
                                notification = await asyncio.wait_for(
                                    websocket.receive_json(),
                                    timeout=WEBSOCKET_TIMEOUT,
                                )

                                # Ensure that any notifications received after the disconnect command has been executed are not processed
                                if not self._websocket_listeners_active:
                                    break

                                await self._on_message(notification)

                        # Disconnect
                        self.websocket_connected = False
                        await websocket.close()
                        return

            except (
                ClientConnectorError,
                ClientOSError,
                TypeError,
                ServerTimeoutError,
            ) as error:
                if self.websocket_connected:
                    logger.debug("%s : %s - %s", host, type(error), error)
                    self.websocket_connected = False

                    if self._on_connection_lost:
                        await self._trigger_callback(self._on_connection_lost)

                if not self.websocket_reconnect:
                    logger.error("%s : %s - %s", host, type(error), error)
                    self.disconnect_notifications()
                    return

                await asyncio.sleep(WEBSOCKET_TIMEOUT)

    @dataclass
    class _ResponseWrapper:
        """Wrapper class for deserializing WebSocket response."""

        data: str

    async def _on_message(self, notification) -> None:
        """Handle WebSocket notifications."""

        # Get the object type and deserialized object.
        try:
            notification_type = notification["eventType"]

            deserialized_data = self.api_client.deserialize(
                self._ResponseWrapper(json.dumps(notification)), notification_type
            ).event_data

        except (ValueError, AttributeError) as error:
            logger.error(
                "%s unable to deserialize WebSocket notification: (%s : %s) with error: (%s : %s)",
                self.host,
                notification_type,
                notification,
                type(error),
                error,
            )
            return

        # Ensure that only valid notifications trigger callbacks
        if deserialized_data is None:
            return

        # Handle all notifications if defined
        if self._on_all_notifications:
            await self._trigger_callback(
                self._on_all_notifications,
                notification,
                refactor_name(notification_type),
            )

        if self._on_all_notifications_raw:
            await self._trigger_callback(self._on_all_notifications_raw, notification)

        # Handle specific notifications if defined
        triggered_notification = self._notification_callbacks[notification_type]

        if triggered_notification:
            await self._trigger_callback(triggered_notification, deserialized_data)

    async def _trigger_callback(self, callback, *args):
        """Trigger async or sync callback correctly."""
        if asyncio.iscoroutinefunction(callback):
            await callback(*args)
        else:
            callback(*args)

    def get_on_connection_lost(self, on_connection_lost) -> None:
        """Callback for WebSocket connection lost."""
        self._on_connection_lost = on_connection_lost

    def get_on_connection(self, on_connection) -> None:
        """Callback for WebSocket connection."""
        self._on_connection = on_connection

    def get_all_notifications(self, on_all_notifications) -> None:
        """Callback for all notifications."""
        self._on_all_notifications = on_all_notifications

    def get_all_notifications_raw(self, on_all_notifications_raw) -> None:
        """Callback for all notifications as dict."""
        self._on_all_notifications_raw = on_all_notifications_raw

    # Generated section start

    def get_active_hdmi_input_signal_notifications(
        self, on_active_hdmi_input_signal_notification
    ) -> None:
        """Callback for WebSocketEventActiveHdmiInputSignal notifications."""
        self._notification_callbacks["WebSocketEventActiveHdmiInputSignal"] = (
            on_active_hdmi_input_signal_notification
        )

    def get_active_listening_mode_notifications(
        self, on_active_listening_mode_notification
    ) -> None:
        """Callback for WebSocketEventActiveListeningMode notifications."""
        self._notification_callbacks["WebSocketEventActiveListeningMode"] = (
            on_active_listening_mode_notification
        )

    def get_active_speaker_group_notifications(
        self, on_active_speaker_group_notification
    ) -> None:
        """Callback for WebSocketEventActiveSpeakerGroup notifications."""
        self._notification_callbacks["WebSocketEventActiveSpeakerGroup"] = (
            on_active_speaker_group_notification
        )

    def get_alarm_timer_notifications(self, on_alarm_timer_notification) -> None:
        """Callback for WebSocketEventAlarmTimer notifications."""
        self._notification_callbacks["WebSocketEventAlarmTimer"] = (
            on_alarm_timer_notification
        )

    def get_alarm_triggered_notifications(
        self, on_alarm_triggered_notification
    ) -> None:
        """Callback for WebSocketEventAlarmTriggered notifications."""
        self._notification_callbacks["WebSocketEventAlarmTriggered"] = (
            on_alarm_triggered_notification
        )

    def get_battery_notifications(self, on_battery_notification) -> None:
        """Callback for WebSocketEventBattery notifications."""
        self._notification_callbacks["WebSocketEventBattery"] = on_battery_notification

    def get_beo_remote_button_notifications(
        self, on_beo_remote_button_notification
    ) -> None:
        """Callback for WebSocketEventBeoRemoteButton notifications."""
        self._notification_callbacks["WebSocketEventBeoRemoteButton"] = (
            on_beo_remote_button_notification
        )

    def get_beolink_experiences_result_notifications(
        self, on_beolink_experiences_result_notification
    ) -> None:
        """Callback for WebSocketEventBeolinkExperiencesResult notifications."""
        self._notification_callbacks["WebSocketEventBeolinkExperiencesResult"] = (
            on_beolink_experiences_result_notification
        )

    def get_beolink_join_result_notifications(
        self, on_beolink_join_result_notification
    ) -> None:
        """Callback for WebSocketEventBeolinkJoinResult notifications."""
        self._notification_callbacks["WebSocketEventBeolinkJoinResult"] = (
            on_beolink_join_result_notification
        )

    def get_button_notifications(self, on_button_notification) -> None:
        """Callback for WebSocketEventButton notifications."""
        self._notification_callbacks["WebSocketEventButton"] = on_button_notification

    def get_curtains_notifications(self, on_curtains_notification) -> None:
        """Callback for WebSocketEventCurtains notifications."""
        self._notification_callbacks["WebSocketEventCurtains"] = (
            on_curtains_notification
        )

    def get_hdmi_video_format_signal_notifications(
        self, on_hdmi_video_format_signal_notification
    ) -> None:
        """Callback for WebSocketEventHdmiVideoFormatSignal notifications."""
        self._notification_callbacks["WebSocketEventHdmiVideoFormatSignal"] = (
            on_hdmi_video_format_signal_notification
        )

    def get_notification_notifications(self, on_notification_notification) -> None:
        """Callback for WebSocketEventNotification notifications."""
        self._notification_callbacks["WebSocketEventNotification"] = (
            on_notification_notification
        )

    def get_playback_error_notifications(self, on_playback_error_notification) -> None:
        """Callback for WebSocketEventPlaybackError notifications."""
        self._notification_callbacks["WebSocketEventPlaybackError"] = (
            on_playback_error_notification
        )

    def get_playback_metadata_notifications(
        self, on_playback_metadata_notification
    ) -> None:
        """Callback for WebSocketEventPlaybackMetadata notifications."""
        self._notification_callbacks["WebSocketEventPlaybackMetadata"] = (
            on_playback_metadata_notification
        )

    def get_playback_progress_notifications(
        self, on_playback_progress_notification
    ) -> None:
        """Callback for WebSocketEventPlaybackProgress notifications."""
        self._notification_callbacks["WebSocketEventPlaybackProgress"] = (
            on_playback_progress_notification
        )

    def get_playback_source_notifications(
        self, on_playback_source_notification
    ) -> None:
        """Callback for WebSocketEventPlaybackSource notifications."""
        self._notification_callbacks["WebSocketEventPlaybackSource"] = (
            on_playback_source_notification
        )

    def get_playback_state_notifications(self, on_playback_state_notification) -> None:
        """Callback for WebSocketEventPlaybackState notifications."""
        self._notification_callbacks["WebSocketEventPlaybackState"] = (
            on_playback_state_notification
        )

    def get_power_state_notifications(self, on_power_state_notification) -> None:
        """Callback for WebSocketEventPowerState notifications."""
        self._notification_callbacks["WebSocketEventPowerState"] = (
            on_power_state_notification
        )

    def get_puc_install_remote_id_status_notifications(
        self, on_puc_install_remote_id_status_notification
    ) -> None:
        """Callback for WebSocketEventPucInstallRemoteIdStatus notifications."""
        self._notification_callbacks["WebSocketEventPucInstallRemoteIdStatus"] = (
            on_puc_install_remote_id_status_notification
        )

    def get_role_notifications(self, on_role_notification) -> None:
        """Callback for WebSocketEventRole notifications."""
        self._notification_callbacks["WebSocketEventRole"] = on_role_notification

    def get_room_compensation_current_measurement_event_notifications(
        self, on_room_compensation_current_measurement_event_notification
    ) -> None:
        """Callback for WebSocketEventRoomCompensationCurrentMeasurementEvent notifications."""
        self._notification_callbacks[
            "WebSocketEventRoomCompensationCurrentMeasurementEvent"
        ] = on_room_compensation_current_measurement_event_notification

    def get_room_compensation_state_notifications(
        self, on_room_compensation_state_notification
    ) -> None:
        """Callback for WebSocketEventRoomCompensationState notifications."""
        self._notification_callbacks["WebSocketEventRoomCompensationState"] = (
            on_room_compensation_state_notification
        )

    def get_software_update_state_notifications(
        self, on_software_update_state_notification
    ) -> None:
        """Callback for WebSocketEventSoftwareUpdateState notifications."""
        self._notification_callbacks["WebSocketEventSoftwareUpdateState"] = (
            on_software_update_state_notification
        )

    def get_sound_settings_notifications(self, on_sound_settings_notification) -> None:
        """Callback for WebSocketEventSoundSettings notifications."""
        self._notification_callbacks["WebSocketEventSoundSettings"] = (
            on_sound_settings_notification
        )

    def get_source_change_notifications(self, on_source_change_notification) -> None:
        """Callback for WebSocketEventSourceChange notifications."""
        self._notification_callbacks["WebSocketEventSourceChange"] = (
            on_source_change_notification
        )

    def get_speaker_group_changed_notifications(
        self, on_speaker_group_changed_notification
    ) -> None:
        """Callback for WebSocketEventSpeakerGroupChanged notifications."""
        self._notification_callbacks["WebSocketEventSpeakerGroupChanged"] = (
            on_speaker_group_changed_notification
        )

    def get_speaker_link_status_changed_notifications(
        self, on_speaker_link_status_changed_notification
    ) -> None:
        """Callback for WebSocketEventSpeakerLinkStatusChanged notifications."""
        self._notification_callbacks["WebSocketEventSpeakerLinkStatusChanged"] = (
            on_speaker_link_status_changed_notification
        )

    def get_stand_connected_notifications(
        self, on_stand_connected_notification
    ) -> None:
        """Callback for WebSocketEventStandConnected notifications."""
        self._notification_callbacks["WebSocketEventStandConnected"] = (
            on_stand_connected_notification
        )

    def get_stand_position_notifications(self, on_stand_position_notification) -> None:
        """Callback for WebSocketEventStandPosition notifications."""
        self._notification_callbacks["WebSocketEventStandPosition"] = (
            on_stand_position_notification
        )

    def get_tv_info_notifications(self, on_tv_info_notification) -> None:
        """Callback for WebSocketEventTvInfo notifications."""
        self._notification_callbacks["WebSocketEventTvInfo"] = on_tv_info_notification

    def get_volume_notifications(self, on_volume_notification) -> None:
        """Callback for WebSocketEventVolume notifications."""
        self._notification_callbacks["WebSocketEventVolume"] = on_volume_notification

    def get_wisa_out_state_notifications(self, on_wisa_out_state_notification) -> None:
        """Callback for WebSocketEventWisaOutState notifications."""
        self._notification_callbacks["WebSocketEventWisaOutState"] = (
            on_wisa_out_state_notification
        )

    # Generated section end



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union

try:
    from pydantic.v1 import (
        BaseModel,
        Field,
        StrictBool,
        StrictFloat,
        StrictInt,
        StrictStr,
    )
except ImportError:
    from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr


class SoundAdjustments(BaseModel):
    """
    SoundAdjustments
    """

    ambience: Optional[Union[StrictFloat, StrictInt]] = None
    bass: Optional[StrictInt] = None
    directivity: Optional[StrictStr] = None
    eco_mode: Optional[StrictBool] = Field(default=None, alias="ecoMode")
    fadein: Optional[StrictBool] = None
    loudness: Optional[StrictBool] = None
    treble: Optional[StrictInt] = None
    __properties = [
        "ambience",
        "bass",
        "directivity",
        "ecoMode",
        "fadein",
        "loudness",
        "treble",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SoundAdjustments:
        """Create an instance of SoundAdjustments from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SoundAdjustments:
        """Create an instance of SoundAdjustments from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SoundAdjustments.parse_obj(obj)

        _obj = SoundAdjustments.parse_obj(
            {
                "ambience": obj.get("ambience"),
                "bass": obj.get("bass"),
                "directivity": obj.get("directivity"),
                "eco_mode": obj.get("ecoMode"),
                "fadein": obj.get("fadein"),
                "loudness": obj.get("loudness"),
                "treble": obj.get("treble"),
            }
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional

try:
    from pydantic.v1 import BaseModel, Field, StrictBool, StrictStr, validator
except ImportError:
    from pydantic import BaseModel, Field, StrictBool, StrictStr, validator


class VideoPixelFormat(BaseModel):
    """
    VideoPixelFormat
    """

    bitdepth: Optional[StrictStr] = None
    chroma_subsample: Optional[StrictStr] = Field(default=None, alias="chromaSubsample")
    colorimetry: Optional[StrictStr] = None
    full_range: Optional[StrictBool] = Field(default=None, alias="fullRange")
    __properties = ["bitdepth", "chromaSubsample", "colorimetry", "fullRange"]

    @validator("bitdepth")
    def bitdepth_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("bit8", "bit10", "bit12"):
            raise ValueError("must be one of enum values ('bit8', 'bit10', 'bit12')")
        return value

    @validator("chroma_subsample")
    def chroma_subsample_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("yCbCr444RGB", "yCbCr422", "yCbCr420"):
            raise ValueError(
                "must be one of enum values ('yCbCr444RGB', 'yCbCr422', 'yCbCr420')"
            )
        return value

    @validator("colorimetry")
    def colorimetry_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in (
            "rGB",
            "opRGB",
            "rGBP3D65",
            "rGBP3DCI",
            "rGB2020",
            "yCC601",
            "yCC709",
            "xvYCC601",
            "xvYCC709",
            "sYCC601",
            "opYCC601",
            "yCC2020NCL",
            "yCC2020NL",
        ):
            raise ValueError(
                "must be one of enum values ('rGB', 'opRGB', 'rGBP3D65', 'rGBP3DCI', 'rGB2020', 'yCC601', 'yCC709', 'xvYCC601', 'xvYCC709', 'sYCC601', 'opYCC601', 'yCC2020NCL', 'yCC2020NL')"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> VideoPixelFormat:
        """Create an instance of VideoPixelFormat from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> VideoPixelFormat:
        """Create an instance of VideoPixelFormat from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return VideoPixelFormat.parse_obj(obj)

        _obj = VideoPixelFormat.parse_obj(
            {
                "bitdepth": obj.get("bitdepth"),
                "chroma_subsample": obj.get("chromaSubsample"),
                "colorimetry": obj.get("colorimetry"),
                "full_range": obj.get("fullRange"),
            }
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional

try:
    from pydantic.v1 import BaseModel, Field, StrictStr, conlist, validator
except ImportError:
    from pydantic import BaseModel, Field, StrictStr, conlist, validator

from mozart_api.models.room_compensation_response import RoomCompensationResponse
from mozart_api.models.speaker_group import SpeakerGroup


class RoomCompensationResult(BaseModel):
    """
    RoomCompensationResult
    """

    compensation: Optional[conlist(RoomCompensationResponse)] = None
    measured_response: Optional[conlist(RoomCompensationResponse)] = Field(
        default=None, alias="measuredResponse"
    )
    placement: Optional[StrictStr] = None
    reference_response: Optional[conlist(RoomCompensationResponse)] = Field(
        default=None, alias="referenceResponse"
    )
    speaker_group_suggestion: Optional[SpeakerGroup] = Field(
        default=None, alias="speakerGroupSuggestion"
    )
    time_stamp: Optional[datetime] = Field(default=None, alias="timeStamp")
    __properties = [
        "compensation",
        "measuredResponse",
        "placement",
        "referenceResponse",
        "speakerGroupSuggestion",
        "timeStamp",
    ]

    @validator("placement")
    def placement_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("free", "nearWall", "unknown"):
            raise ValueError(
                "must be one of enum values ('free', 'nearWall', 'unknown')"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RoomCompensationResult:
        """Create an instance of RoomCompensationResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in compensation (list)
        _items = []
        if self.compensation:
            for _item in self.compensation:
                if _item:
                    _items.append(_item.to_dict())
            _dict["compensation"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in measured_response (list)
        _items = []
        if self.measured_response:
            for _item in self.measured_response:
                if _item:
                    _items.append(_item.to_dict())
            _dict["measuredResponse"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in reference_response (list)
        _items = []
        if self.reference_response:
            for _item in self.reference_response:
                if _item:
                    _items.append(_item.to_dict())
            _dict["referenceResponse"] = _items
        # override the default output from pydantic by calling `to_dict()` of speaker_group_suggestion
        if self.speaker_group_suggestion:
            _dict["speakerGroupSuggestion"] = self.speaker_group_suggestion.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RoomCompensationResult:
        """Create an instance of RoomCompensationResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RoomCompensationResult.parse_obj(obj)

        _obj = RoomCompensationResult.parse_obj(
            {
                "compensation": (
                    [
                        RoomCompensationResponse.from_dict(_item)
                        for _item in obj.get("compensation")
                    ]
                    if obj.get("compensation") is not None
                    else None
                ),
                "measured_response": (
                    [
                        RoomCompensationResponse.from_dict(_item)
                        for _item in obj.get("measuredResponse")
                    ]
                    if obj.get("measuredResponse") is not None
                    else None
                ),
                "placement": obj.get("placement"),
                "reference_response": (
                    [
                        RoomCompensationResponse.from_dict(_item)
                        for _item in obj.get("referenceResponse")
                    ]
                    if obj.get("referenceResponse") is not None
                    else None
                ),
                "speaker_group_suggestion": (
                    SpeakerGroup.from_dict(obj.get("speakerGroupSuggestion"))
                    if obj.get("speakerGroupSuggestion") is not None
                    else None
                ),
                "time_stamp": obj.get("timeStamp"),
            }
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional

try:
    from pydantic.v1 import BaseModel, Field, StrictBool, StrictStr
except ImportError:
    from pydantic import BaseModel, Field, StrictBool, StrictStr

from mozart_api.models.source_type_enum import SourceTypeEnum


class Source(BaseModel):
    """
    Source
    """

    id: Optional[StrictStr] = None
    is_enabled: Optional[StrictBool] = Field(
        default=None,
        alias="isEnabled",
        description="some sources require an explicit activation or accept of terms before being enabled",
    )
    is_multiroom_available: Optional[StrictBool] = Field(
        default=None, alias="isMultiroomAvailable"
    )
    is_playable: Optional[StrictBool] = Field(default=None, alias="isPlayable")
    name: Optional[StrictStr] = None
    type: Optional[SourceTypeEnum] = None
    __properties = [
        "id",
        "isEnabled",
        "isMultiroomAvailable",
        "isPlayable",
        "name",
        "type",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Source:
        """Create an instance of Source from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of type
        if self.type:
            _dict["type"] = self.type.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Source:
        """Create an instance of Source from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Source.parse_obj(obj)

        _obj = Source.parse_obj(
            {
                "id": obj.get("id"),
                "is_enabled": obj.get("isEnabled"),
                "is_multiroom_available": obj.get("isMultiroomAvailable"),
                "is_playable": obj.get("isPlayable"),
                "name": obj.get("name"),
                "type": (
                    SourceTypeEnum.from_dict(obj.get("type"))
                    if obj.get("type") is not None
                    else None
                ),
            }
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union

try:
    from pydantic.v1 import BaseModel, Field, StrictStr, confloat, conint, validator
except ImportError:
    from pydantic import BaseModel, Field, StrictStr, confloat, conint, validator

from mozart_api.models.play_queue_item import PlayQueueItem
from mozart_api.models.play_queue_settings import PlayQueueSettings
from mozart_api.models.source_type_enum import SourceTypeEnum
from mozart_api.models.stand_position import StandPosition


class Action(BaseModel):
    """
    An action object. Examples:  RadioAction: ```json {   \"type\": \"radio\",   \"radioStationId\": \"8779112938791514\" } ```  ToneAction: ```json {   \"type\": \"tone\",   \"toneName\": \"alarm_2\" } ```  SourcePresetAction: ```json {   \"type\": \"sourcePreset\",   \"source\": {     \"value\": \"spotify\"   },   \"presetKey\": \"Preset3\" } ```  DeezerFlowAction: ```json {   \"type\": \"deezerFlow\",   \"deezerUserId\": \"1234\" } ```  ActivateSourceAction: ```json {   \"type\": \"activateSource\",   \"source\": {     \"value\": \"spotify\"   } } ```  PlayQueueAction: ```   {     \"type\": \"playQueue\",     \"queueItem\": {       \"provider\": {         \"value\": \"deezer\"       },       \"startNowFromPosition\": 0,       \"type\": \"playlist\",       \"uri\": \"playlist:8074581462\"     },     \"queueSettings\": {       \"consume\": false,       \"repeat\": \"none\",       \"shuffle\": false     }   } ```  StandbyAction: ```json {   \"type\": \"standby\" } ```  AllStandbyAction: ```json {   \"type\": \"allStandby\" } ```  TouchToJoinAction: ```json {   \"type\": \"touchToJoin\" } ```  ButtonShortPressAction: ```json {   \"type\": \"buttonShortPress\",   \"buttonName\": \"preset1\" } ```  FallbackAction: ```json {   \"type\": \"fallback\" } ```  VolumeAction: ```json {   \"type\": \"volume\",   \"volumeLevel\": 25 } ```  StopAction: ```json {   \"type\": \"stop\",   \"stopDuration\": 1300 } ```  TriggerContentAction: ```json {   \"contentId\": \"tv://netflix\",   \"type\": \"triggerContent\" } ```  SpeakerGroupAction: ```json {   \"type\": \"speakerGroup\",   \"speakerGroupId\": \"00112233-4455-6677-8899-aabbccddeeff\" } ```  ListeningModeAction: ```json {   \"type\": \"listeningMode\",   \"listeningModeId\": 1234 } ```  StandAction: ```json {   \"type\": \"stand\",   \"standPosition\": {     \"angle\": 7.5   } } ```  GainAction: ```json {   \"type\": \"sourceGain\",   \"source\": {     \"value\": \"spotify\"   },   \"gainDb\": 1.0 } ```   # noqa: E501
    """

    button_name: Optional[StrictStr] = Field(
        default=None,
        alias="buttonName",
        description="Name of the Button used for button-press types ('buttonShortPress')",
    )
    content_id: Optional[StrictStr] = Field(
        default=None,
        alias="contentId",
        description="Id of content only used for 'type=triggerContent'",
    )
    deezer_user_id: Optional[StrictStr] = Field(
        default=None,
        alias="deezerUserId",
        description="Id of user only used for 'type=deezerFlow' and is optional",
    )
    gain_db: Optional[
        Union[confloat(le=12, ge=-12, strict=True), conint(le=12, ge=-12, strict=True)]
    ] = Field(
        default=None, alias="gainDb", description="Only usef for 'type=sourceGain'"
    )
    listening_mode_id: Optional[conint(strict=True, ge=0)] = Field(
        default=None, alias="listeningModeId"
    )
    preset_key: Optional[StrictStr] = Field(
        default=None, alias="presetKey", description="Only used for 'type=sourcePreset'"
    )
    queue_item: Optional[PlayQueueItem] = Field(default=None, alias="queueItem")
    queue_settings: Optional[PlayQueueSettings] = Field(
        default=None, alias="queueSettings"
    )
    radio_station_id: Optional[StrictStr] = Field(
        default=None,
        alias="radioStationId",
        description="Id of RadioStation only used for 'type=radio'",
    )
    source: Optional[SourceTypeEnum] = None
    speaker_group_id: Optional[StrictStr] = Field(default=None, alias="speakerGroupId")
    stand_position: Optional[StandPosition] = Field(default=None, alias="standPosition")
    stop_duration: Optional[conint(strict=True, ge=0)] = Field(
        default=None,
        alias="stopDuration",
        description="The duration to wait (seconds) until stopping only used for 'type=stop'",
    )
    tone_name: Optional[StrictStr] = Field(
        default=None,
        alias="toneName",
        description="Name of the tone only used for 'type=tone'",
    )
    type: StrictStr = Field(default=..., description="The type of Action")
    volume_level: Optional[conint(strict=True, le=100, ge=0)] = Field(
        default=None,
        alias="volumeLevel",
        description="The volume level to configure only used for 'type=volume'",
    )
    __properties = [
        "buttonName",
        "contentId",
        "deezerUserId",
        "gainDb",
        "listeningModeId",
        "presetKey",
        "queueItem",
        "queueSettings",
        "radioStationId",
        "source",
        "speakerGroupId",
        "standPosition",
        "stopDuration",
        "toneName",
        "type",
        "volumeLevel",
    ]

    @validator("button_name")
    def button_name_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("preset1", "preset2", "preset3", "preset4"):
            raise ValueError(
                "must be one of enum values ('preset1', 'preset2', 'preset3', 'preset4')"
            )
        return value

    @validator("tone_name")
    def tone_name_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("alarm_1", "alarm_2"):
            raise ValueError("must be one of enum values ('alarm_1', 'alarm_2')")
        return value

    @validator("type")
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in (
            "standby",
            "tone",
            "radio",
            "sourcePreset",
            "deezerFlow",
            "activateSource",
            "playQueue",
            "buttonShortPress",
            "allStandby",
            "touchToJoin",
            "fallback",
            "volume",
            "stop",
            "triggerContent",
            "speakerGroup",
            "listeningMode",
            "stand",
            "sourceGain",
        ):
            raise ValueError(
                "must be one of enum values ('standby', 'tone', 'radio', 'sourcePreset', 'deezerFlow', 'activateSource', 'playQueue', 'buttonShortPress', 'allStandby', 'touchToJoin', 'fallback', 'volume', 'stop', 'triggerContent', 'speakerGroup', 'listeningMode', 'stand', 'sourceGain')"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Action:
        """Create an instance of Action from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of queue_item
        if self.queue_item:
            _dict["queueItem"] = self.queue_item.to_dict()
        # override the default output from pydantic by calling `to_dict()` of queue_settings
        if self.queue_settings:
            _dict["queueSettings"] = self.queue_settings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of source
        if self.source:
            _dict["source"] = self.source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of stand_position
        if self.stand_position:
            _dict["standPosition"] = self.stand_position.to_dict()
        # set to None if button_name (nullable) is None
        # and __fields_set__ contains the field
        if self.button_name is None and "button_name" in self.__fields_set__:
            _dict["buttonName"] = None

        # set to None if content_id (nullable) is None
        # and __fields_set__ contains the field
        if self.content_id is None and "content_id" in self.__fields_set__:
            _dict["contentId"] = None

        # set to None if deezer_user_id (nullable) is None
        # and __fields_set__ contains the field
        if self.deezer_user_id is None and "deezer_user_id" in self.__fields_set__:
            _dict["deezerUserId"] = None

        # set to None if preset_key (nullable) is None
        # and __fields_set__ contains the field
        if self.preset_key is None and "preset_key" in self.__fields_set__:
            _dict["presetKey"] = None

        # set to None if radio_station_id (nullable) is None
        # and __fields_set__ contains the field
        if self.radio_station_id is None and "radio_station_id" in self.__fields_set__:
            _dict["radioStationId"] = None

        # set to None if stop_duration (nullable) is None
        # and __fields_set__ contains the field
        if self.stop_duration is None and "stop_duration" in self.__fields_set__:
            _dict["stopDuration"] = None

        # set to None if tone_name (nullable) is None
        # and __fields_set__ contains the field
        if self.tone_name is None and "tone_name" in self.__fields_set__:
            _dict["toneName"] = None

        # set to None if volume_level (nullable) is None
        # and __fields_set__ contains the field
        if self.volume_level is None and "volume_level" in self.__fields_set__:
            _dict["volumeLevel"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Action:
        """Create an instance of Action from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Action.parse_obj(obj)

        _obj = Action.parse_obj(
            {
                "button_name": obj.get("buttonName"),
                "content_id": obj.get("contentId"),
                "deezer_user_id": obj.get("deezerUserId"),
                "gain_db": obj.get("gainDb"),
                "listening_mode_id": obj.get("listeningModeId"),
                "preset_key": obj.get("presetKey"),
                "queue_item": (
                    PlayQueueItem.from_dict(obj.get("queueItem"))
                    if obj.get("queueItem") is not None
                    else None
                ),
                "queue_settings": (
                    PlayQueueSettings.from_dict(obj.get("queueSettings"))
                    if obj.get("queueSettings") is not None
                    else None
                ),
                "radio_station_id": obj.get("radioStationId"),
                "source": (
                    SourceTypeEnum.from_dict(obj.get("source"))
                    if obj.get("source") is not None
                    else None
                ),
                "speaker_group_id": obj.get("speakerGroupId"),
                "stand_position": (
                    StandPosition.from_dict(obj.get("standPosition"))
                    if obj.get("standPosition") is not None
                    else None
                ),
                "stop_duration": obj.get("stopDuration"),
                "tone_name": obj.get("toneName"),
                "type": obj.get("type"),
                "volume_level": obj.get("volumeLevel"),
            }
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List

try:
    from pydantic.v1 import BaseModel, Field, conlist
except ImportError:
    from pydantic import BaseModel, Field, conlist

from mozart_api.models.ambience import Ambience


class AmbienceRange(BaseModel):
    """
    AmbienceRange
    """

    default: Ambience = Field(...)
    range: conlist(Ambience, unique_items=True) = Field(
        default=..., description="Product and role specific ambience range"
    )
    __properties = ["default", "range"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AmbienceRange:
        """Create an instance of AmbienceRange from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of default
        if self.default:
            _dict["default"] = self.default.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in range (list)
        _items = []
        if self.range:
            for _item in self.range:
                if _item:
                    _items.append(_item.to_dict())
            _dict["range"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AmbienceRange:
        """Create an instance of AmbienceRange from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AmbienceRange.parse_obj(obj)

        _obj = AmbienceRange.parse_obj(
            {
                "default": (
                    Ambience.from_dict(obj.get("default"))
                    if obj.get("default") is not None
                    else None
                ),
                "range": (
                    [Ambience.from_dict(_item) for _item in obj.get("range")]
                    if obj.get("range") is not None
                    else None
                ),
            }
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Union

try:
    from pydantic.v1 import BaseModel, Field, StrictFloat, StrictInt
except ImportError:
    from pydantic import BaseModel, Field, StrictFloat, StrictInt


class SpeechEnhance(BaseModel):
    """
    SpeechEnhance
    """

    value: Union[StrictFloat, StrictInt] = Field(
        default=..., description="Selected speech-enhance value"
    )
    __properties = ["value"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SpeechEnhance:
        """Create an instance of SpeechEnhance from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SpeechEnhance:
        """Create an instance of SpeechEnhance from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SpeechEnhance.parse_obj(obj)

        _obj = SpeechEnhance.parse_obj({"value": obj.get("value")})
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional

try:
    from pydantic.v1 import BaseModel, Field, StrictStr, validator
except ImportError:
    from pydantic import BaseModel, Field, StrictStr, validator


class RemoteUIKeyState(BaseModel):
    """
    RemoteUIKeyState
    """

    state: Optional[StrictStr] = Field(
        default=None,
        description="The state of the pressed key. ShortPress and LongPress's duration are determined by the remote. Whereas Down, Continue, and Release reflect the state of the key and press duration is the time between a Down and a Release state. Continue indicates that a button is pressed and the key event should be handled multiple times until a release is received. ",
    )
    __properties = ["state"]

    @validator("state")
    def state_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("ShortPress", "LongPress", "Down", "Continue", "Release"):
            raise ValueError(
                "must be one of enum values ('ShortPress', 'LongPress', 'Down', 'Continue', 'Release')"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RemoteUIKeyState:
        """Create an instance of RemoteUIKeyState from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RemoteUIKeyState:
        """Create an instance of RemoteUIKeyState from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RemoteUIKeyState.parse_obj(obj)

        _obj = RemoteUIKeyState.parse_obj({"state": obj.get("state")})
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional

try:
    from pydantic.v1 import BaseModel, Field, StrictBool, StrictStr, validator
except ImportError:
    from pydantic import BaseModel, Field, StrictBool, StrictStr, validator

from mozart_api.models.room_compensation_error_details import (
    RoomCompensationErrorDetails,
)
from mozart_api.models.room_compensation_properties import RoomCompensationProperties


class RoomCompensationState(BaseModel):
    """
    RoomCompensationState
    """

    state: Optional[StrictStr] = None
    error: Optional[StrictStr] = Field(
        default=None,
        description="microphoneMuted:   The microphone is muted (soft-off, using touch button). microphoneSwitchOff:   The microphone switch is set in its off position. microphoneSignalMissing:   No signal was detected. Is the microphone blocked? externalMicrophoneMissing:   The external microphone is not connected.   Is only relevant for advanced room compensation. externalMicrophoneInvalidPosition:   The external microphone is placed in an invalid position,   e.g. placed too close or in an extreme angle to the internal speakers.   Is only relevant for advanced room compensation. noisyEnvironment:   Too much environment noise to get a valid measurement. speakerMeasurementFailed:   A measurement failed, related to one of the individual speakers.   See the errorDetails property for details about the error and which speaker measurement failed.   Is only relevant for advanced room compensation. invalidSpeakerList:   The speaker list contains invalid speakers.   Valid speakers are: all external speakers and non-virtual internal speakers.   Is only relevant for advanced room compensation. invalidAction:   Could not start with given action.   Eg. can't run from last failed speaker if there isn't any failed run.   Is only relevant for advanced room compensation. internalError:   Internal product error. ",
    )
    error_details: Optional[RoomCompensationErrorDetails] = Field(
        default=None, alias="errorDetails"
    )
    last_run_available: Optional[StrictBool] = Field(
        default=None,
        alias="lastRunAvailable",
        description='When true, measurements have been cached due to manual interrupt or failure, making it possible to use the action "continue" where the system will continue from the speaker where interrupted. The cached measurements are only temporary and will be cleared after some time (default 15min), in which case lastRunAvailable becomes false. ',
    )
    properties: Optional[RoomCompensationProperties] = None
    time_stamp: Optional[datetime] = Field(default=None, alias="timeStamp")
    __properties = [
        "state",
        "error",
        "errorDetails",
        "lastRunAvailable",
        "properties",
        "timeStamp",
    ]

    @validator("state")
    def state_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("notStarted", "running", "done", "error", "stopped"):
            raise ValueError(
                "must be one of enum values ('notStarted', 'running', 'done', 'error', 'stopped')"
            )
        return value

    @validator("error")
    def error_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in (
            "noError",
            "microphoneMuted",
            "microphoneSwitchOff",
            "microphoneSignalMissing",
            "externalMicrophoneMissing",
            "externalMicrophoneInvalidPosition",
            "noisyEnvironment",
            "speakerMeasurementFailed",
            "invalidSpeakerList",
            "invalidAction",
            "internalError",
        ):
            raise ValueError(
                "must be one of enum values ('noError', 'microphoneMuted', 'microphoneSwitchOff', 'microphoneSignalMissing', 'externalMicrophoneMissing', 'externalMicrophoneInvalidPosition', 'noisyEnvironment', 'speakerMeasurementFailed', 'invalidSpeakerList', 'invalidAction', 'internalError')"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RoomCompensationState:
        """Create an instance of RoomCompensationState from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of error_details
        if self.error_details:
            _dict["errorDetails"] = self.error_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of properties
        if self.properties:
            _dict["properties"] = self.properties.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RoomCompensationState:
        """Create an instance of RoomCompensationState from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RoomCompensationState.parse_obj(obj)

        _obj = RoomCompensationState.parse_obj(
            {
                "state": obj.get("state"),
                "error": obj.get("error"),
                "error_details": (
                    RoomCompensationErrorDetails.from_dict(obj.get("errorDetails"))
                    if obj.get("errorDetails") is not None
                    else None
                ),
                "last_run_available": obj.get("lastRunAvailable"),
                "properties": (
                    RoomCompensationProperties.from_dict(obj.get("properties"))
                    if obj.get("properties") is not None
                    else None
                ),
                "time_stamp": obj.get("timeStamp"),
            }
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional

try:
    from pydantic.v1 import BaseModel, Field
except ImportError:
    from pydantic import BaseModel, Field

from mozart_api.models.ambience_feature import AmbienceFeature
from mozart_api.models.balance_feature import BalanceFeature
from mozart_api.models.bass_feature import BassFeature
from mozart_api.models.bass_management_feature import BassManagementFeature
from mozart_api.models.compression_feature import CompressionFeature
from mozart_api.models.directivity_feature import DirectivityFeature
from mozart_api.models.fader_feature import FaderFeature
from mozart_api.models.room_compensation_feature import RoomCompensationFeature
from mozart_api.models.spatial_envelopment_feature import SpatialEnvelopmentFeature
from mozart_api.models.spatial_height_feature import SpatialHeightFeature
from mozart_api.models.spatial_processing_feature import SpatialProcessingFeature
from mozart_api.models.spatial_surround_feature import SpatialSurroundFeature
from mozart_api.models.spatial_width_feature import SpatialWidthFeature
from mozart_api.models.speech_enhance_feature import SpeechEnhanceFeature
from mozart_api.models.tone_touch_x_feature import ToneTouchXFeature
from mozart_api.models.tone_touch_y_feature import ToneTouchYFeature
from mozart_api.models.treble_feature import TrebleFeature


class SoundFeatureSet(BaseModel):
    """
    SoundFeatureSet
    """

    ambience: Optional[AmbienceFeature] = None
    balance: Optional[BalanceFeature] = None
    bass: Optional[BassFeature] = None
    bass_management: Optional[BassManagementFeature] = Field(
        default=None, alias="bass-management"
    )
    compression: Optional[CompressionFeature] = None
    directivity: Optional[DirectivityFeature] = None
    fader: Optional[FaderFeature] = None
    room_compensation: Optional[RoomCompensationFeature] = Field(
        default=None, alias="roomCompensation"
    )
    spatial_envelopment: Optional[SpatialEnvelopmentFeature] = Field(
        default=None, alias="spatial-envelopment"
    )
    spatial_height: Optional[SpatialHeightFeature] = Field(
        default=None, alias="spatial-height"
    )
    spatial_processing: Optional[SpatialProcessingFeature] = Field(
        default=None, alias="spatial-processing"
    )
    spatial_surround: Optional[SpatialSurroundFeature] = Field(
        default=None, alias="spatial-surround"
    )
    spatial_width: Optional[SpatialWidthFeature] = Field(
        default=None, alias="spatial-width"
    )
    speech_enhance: Optional[SpeechEnhanceFeature] = Field(
        default=None, alias="speech-enhance"
    )
    tone_touch_x: Optional[ToneTouchXFeature] = Field(default=None, alias="toneTouchX")
    tone_touch_y: Optional[ToneTouchYFeature] = Field(default=None, alias="toneTouchY")
    treble: Optional[TrebleFeature] = None
    __properties = [
        "ambience",
        "balance",
        "bass",
        "bass-management",
        "compression",
        "directivity",
        "fader",
        "roomCompensation",
        "spatial-envelopment",
        "spatial-height",
        "spatial-processing",
        "spatial-surround",
        "spatial-width",
        "speech-enhance",
        "toneTouchX",
        "toneTouchY",
        "treble",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SoundFeatureSet:
        """Create an instance of SoundFeatureSet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of ambience
        if self.ambience:
            _dict["ambience"] = self.ambience.to_dict()
        # override the default output from pydantic by calling `to_dict()` of balance
        if self.balance:
            _dict["balance"] = self.balance.to_dict()
        # override the default output from pydantic by calling `to_dict()` of bass
        if self.bass:
            _dict["bass"] = self.bass.to_dict()
        # override the default output from pydantic by calling `to_dict()` of bass_management
        if self.bass_management:
            _dict["bass-management"] = self.bass_management.to_dict()
        # override the default output from pydantic by calling `to_dict()` of compression
        if self.compression:
            _dict["compression"] = self.compression.to_dict()
        # override the default output from pydantic by calling `to_dict()` of directivity
        if self.directivity:
            _dict["directivity"] = self.directivity.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fader
        if self.fader:
            _dict["fader"] = self.fader.to_dict()
        # override the default output from pydantic by calling `to_dict()` of room_compensation
        if self.room_compensation:
            _dict["roomCompensation"] = self.room_compensation.to_dict()
        # override the default output from pydantic by calling `to_dict()` of spatial_envelopment
        if self.spatial_envelopment:
            _dict["spatial-envelopment"] = self.spatial_envelopment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of spatial_height
        if self.spatial_height:
            _dict["spatial-height"] = self.spatial_height.to_dict()
        # override the default output from pydantic by calling `to_dict()` of spatial_processing
        if self.spatial_processing:
            _dict["spatial-processing"] = self.spatial_processing.to_dict()
        # override the default output from pydantic by calling `to_dict()` of spatial_surround
        if self.spatial_surround:
            _dict["spatial-surround"] = self.spatial_surround.to_dict()
        # override the default output from pydantic by calling `to_dict()` of spatial_width
        if self.spatial_width:
            _dict["spatial-width"] = self.spatial_width.to_dict()
        # override the default output from pydantic by calling `to_dict()` of speech_enhance
        if self.speech_enhance:
            _dict["speech-enhance"] = self.speech_enhance.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tone_touch_x
        if self.tone_touch_x:
            _dict["toneTouchX"] = self.tone_touch_x.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tone_touch_y
        if self.tone_touch_y:
            _dict["toneTouchY"] = self.tone_touch_y.to_dict()
        # override the default output from pydantic by calling `to_dict()` of treble
        if self.treble:
            _dict["treble"] = self.treble.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SoundFeatureSet:
        """Create an instance of SoundFeatureSet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SoundFeatureSet.parse_obj(obj)

        _obj = SoundFeatureSet.parse_obj(
            {
                "ambience": (
                    AmbienceFeature.from_dict(obj.get("ambience"))
                    if obj.get("ambience") is not None
                    else None
                ),
                "balance": (
                    BalanceFeature.from_dict(obj.get("balance"))
                    if obj.get("balance") is not None
                    else None
                ),
                "bass": (
                    BassFeature.from_dict(obj.get("bass"))
                    if obj.get("bass") is not None
                    else None
                ),
                "bass_management": (
                    BassManagementFeature.from_dict(obj.get("bass-management"))
                    if obj.get("bass-management") is not None
                    else None
                ),
                "compression": (
                    CompressionFeature.from_dict(obj.get("compression"))
                    if obj.get("compression") is not None
                    else None
                ),
                "directivity": (
                    DirectivityFeature.from_dict(obj.get("directivity"))
                    if obj.get("directivity") is not None
                    else None
                ),
                "fader": (
                    FaderFeature.from_dict(obj.get("fader"))
                    if obj.get("fader") is not None
                    else None
                ),
                "room_compensation": (
                    RoomCompensationFeature.from_dict(obj.get("roomCompensation"))
                    if obj.get("roomCompensation") is not None
                    else None
                ),
                "spatial_envelopment": (
                    SpatialEnvelopmentFeature.from_dict(obj.get("spatial-envelopment"))
                    if obj.get("spatial-envelopment") is not None
                    else None
                ),
                "spatial_height": (
                    SpatialHeightFeature.from_dict(obj.get("spatial-height"))
                    if obj.get("spatial-height") is not None
                    else None
                ),
                "spatial_processing": (
                    SpatialProcessingFeature.from_dict(obj.get("spatial-processing"))
                    if obj.get("spatial-processing") is not None
                    else None
                ),
                "spatial_surround": (
                    SpatialSurroundFeature.from_dict(obj.get("spatial-surround"))
                    if obj.get("spatial-surround") is not None
                    else None
                ),
                "spatial_width": (
                    SpatialWidthFeature.from_dict(obj.get("spatial-width"))
                    if obj.get("spatial-width") is not None
                    else None
                ),
                "speech_enhance": (
                    SpeechEnhanceFeature.from_dict(obj.get("speech-enhance"))
                    if obj.get("speech-enhance") is not None
                    else None
                ),
                "tone_touch_x": (
                    ToneTouchXFeature.from_dict(obj.get("toneTouchX"))
                    if obj.get("toneTouchX") is not None
                    else None
                ),
                "tone_touch_y": (
                    ToneTouchYFeature.from_dict(obj.get("toneTouchY"))
                    if obj.get("toneTouchY") is not None
                    else None
                ),
                "treble": (
                    TrebleFeature.from_dict(obj.get("treble"))
                    if obj.get("treble") is not None
                    else None
                ),
            }
        )
        return _obj



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional

try:
    from pydantic.v1 import BaseModel, Field, StrictStr
except ImportError:
    from pydantic import BaseModel, Field, StrictStr

from mozart_api.models.source import Source


class WebSocketEventSourceChange(BaseModel):
    """
    WebSocketEventSourceChange
    """

    event_data: Optional[Source] = Field(default=None, alias="eventData")
    event_type: Optional[StrictStr] = Field(default=None, alias="eventType")
    __properties = ["eventData", "eventType"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WebSocketEventSourceChange:
        """Create an instance of WebSocketEventSourceChange from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of event_data
        if self.event_data:
            _dict["eventData"] = self.event_data.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WebSocketEventSourceChange:
        """Create an instance of WebSocketEventSourceChange from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return WebSocketEventSourceChange.parse_obj(obj)

        _obj = WebSocketEventSourceChange.parse_obj(
            {
                "event_data": (
                    Source.from_dict(obj.get("eventData"))
                    if obj.get("eventData") is not None
                    else None
                ),
                "event_type": obj.get("eventType"),
            }
        )
        return _obj
